@@ -24,6 +24,7 @@
 #include <QFileInfo>
 #include <QTextStream>
 #include <QDate>
+#include <QShortcut>
 
 #include "Dialogs/TreeModel.h"
 #include "Dialogs/AddMetadata.h"
@@ -38,7 +39,8 @@ static const QString SETTINGS_GROUP = "meta_editor";
 MetaEditor::MetaEditor(QWidget *parent)
   : QDialog(parent),
     m_mainWindow(qobject_cast<MainWindow *>(parent)),
-    m_Relator(MarcRelators::instance())
+    m_Relator(MarcRelators::instance()),
+    m_RemoveRow(new QShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_Delete),this, 0, 0, Qt::WidgetWithChildrenShortcut))
 {
     setupUi(this);
 
@@ -76,6 +78,7 @@ MetaEditor::MetaEditor(QWidget *parent)
     connect(delButton, SIGNAL(clicked()), this, SLOT(removeRow()));
     connect(tbMoveUp, SIGNAL(clicked()), this, SLOT(moveRowUp()));
     connect(tbMoveDown, SIGNAL(clicked()), this, SLOT(moveRowDown()));
+    connect(m_RemoveRow, SIGNAL(activated()), this, SLOT(removeRow()));
 
     if (m_version.startsWith('3')) {
         connect(addMetaButton, SIGNAL(clicked()), this, SLOT(selectElement()));
@@ -92,6 +95,12 @@ MetaEditor::MetaEditor(QWidget *parent)
 }
 
 
+MetaEditor::~MetaEditor()
+{
+    m_RemoveRow->deleteLater();
+}
+
+
 QString MetaEditor::GetOPFMetadata() {
     PythonRoutines pr;
     MetadataPieces mdp = pr.GetMetadataInPython(m_opfdata, m_version);
@@ -568,20 +577,20 @@ void MetaEditor::loadMetadataProperties()
          tr("Title Type: main") << "title-type:main" << tr("Indicates the associated title is the main title of the publication.  Only one main title should exist.") <<
          tr("Title Type: subtitle") << "title-type:subtitle" << tr("Indicates that the associated title is a subtitle of the publication if one exists..") <<
          tr("Title Type: short") << "title-type:short" << tr("Indicates that the associated title is a shortened title of the publication if one exists.") <<
-         tr("Title Type: collection") << "title-type:collection" << tr("Indicates that the associated title is the title of a Tcollection that includes this publication belongs to if one exists.") <<
+         tr("Title Type: collection") << "title-type:collection" << tr("Indicates that the associated title is the title of a collection that includes this publication belongs to, if one exists.") <<
          tr("Title Type: edition") << "title-type:edition" << tr("Indicates that the associated title is an edition title for this publications if one exists.") <<
          tr("Title Type: expanded") << "title-type:expanded" << tr("Indicates that the associated title is an expanded title for this publication if one exists.") <<
          tr("Alternate Script") << "alternate-script" << tr("Provides an alternate expression of the associated property value in a language and script identified by an alternate-language attribute.") <<
          tr("Alternate Language") << "altlang" << tr("Language code for the language used in the associated alternate-script property value.") <<
          tr("Collection Type: set") << "collection-type:set" << tr("Property used with belongs-to-collection. Indicates the form or nature of a collection. The value 'set' should be used for a finite collection of works that together constitute a single intellectual unit; typically issued together and able to be sold as a unit..") <<
-         tr("Collection Type: series") << "collection-type:series" << tr("Property used with belongs-to-collection. Indicates the form or nature of a collection. The value 'series'' should be used for asequence of related works that are formally identified as a group; typically open-ended with works issued individually over time.") <<
+         tr("Collection Type: series") << "collection-type:series" << tr("Property used with belongs-to-collection. Indicates the form or nature of a collection. The value 'series'' should be used for a sequence of related works that are formally identified as a group; typically open-ended with works issued individually over time.") <<
          tr("Display Sequence") << "display-seq" << tr("Indicates the numeric position in which to display the current property relative to identical metadata properties (e.g., to indicate the order in which to render multiple titles or multiple authors).") <<
          tr("File as") << "file-as" << tr("Provides the normalized form of the associated property for sorting. Typically used with author, creator, and contributor names.") <<
          tr("Group Position") << "group-position" << tr("Indicates the numeric position in which the EPUB Publication is ordered relative to other works belonging to the same group (whether all EPUB Publications or not).") <<
          tr("Identifier Type") << "identifier-type" << tr("Indicates the form or nature of an identifier. When the identifier-type value is drawn from a code list or other formal enumeration, the scheme attribute should be used to identify its source.") <<
          tr("Meta Authority") << "meta-auth" << tr("Identifies the party or authority responsible for an instance of package metadata.") <<
          tr("Role") << "role" << tr("Describes the nature of work performed by a creator or contributor (e.g., that the person is the author or editor of a work).  Typically used with the marc:relators scheme for a controlled vocabulary.") <<
-         tr("Scheme") << "scheme" << tr("This attribute is typically added to dc:identifier, dc:source: dc:creator, or dc:contributor to indicate the controlled vocabulary system employed. (e.g. marc:relators to specifiy valid values for the role property.") <<
+         tr("Scheme") << "scheme" << tr("This attribute is typically added to dc:identifier, dc:source: dc:creator, or dc:contributor to indicate the controlled vocabulary system employed. (e.g. marc:relators to specify valid values for the role property.") <<
          tr("Source of Pagination") << "source-of" << tr("Indicates a unique aspect of an adapted source resource that has been retained in the given Rendition of the EPUB Publication. This specification defines the pagination value to indicate that the referenced source element is the source of the pagebreak properties defined in the content. This value should be set whenever pagination is included and the print source is known. Valid values: pagination.") <<
          tr("Custom Property") << "[No data]" << tr("An empty metadata property or attribute you can modify.");
 
