@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015              Kevin B. Hendricks  Stratford, ON Canada
+**  Copyright (C) 2015, 2016        Kevin B. Hendricks  Stratford, ON Canada
 **  Copyright (C) 2013              John Schember <john@nachtimwald.com>
 **  Copyright (C) 2009, 2010, 2011  Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
@@ -157,13 +157,11 @@ QString OPFResource::GetText() const
 void OPFResource::SetText(const QString &text)
 {
     QWriteLocker locker(&GetLock());
-    // QString source = CleanSource::ProcessXML(text);
-    QString source = ValidatePackageVersion(CleanSource::ProcessXML(text, "application/oebps-package+xml"));
+    QString source = ValidatePackageVersion(text);
     TextResource::SetText(source);
 }
 
 
-
 QHash <Resource *, int>  OPFResource::GetReadingOrderAll( const QList <Resource *> resources)
 {
     QReadLocker locker(&GetLock());
@@ -709,7 +707,7 @@ QHash <QString, QString>  OPFResource::GetGuideSemanticNameForPaths()
 {
     QString version = GetEpubVersion();
     if (version.startsWith('3')) {
-      NavProcessor navproc(GetNavResource());
+        NavProcessor navproc(GetNavResource());
         return navproc.GetLandmarkNameForPaths();
     }
 
@@ -809,9 +807,9 @@ void OPFResource::ResourceRenamed(const Resource *resource, QString old_full_pat
             QString old_href = me.m_href;
             me.m_href = resource->GetRelativePathToOEBPS();
             old_id = me.m_id;
+            p.m_idpos.remove(old_id);
             new_id = GetUniqueID(GetValidID(resource->Filename()),p);
             me.m_id = new_id;
-            p.m_idpos.remove(old_id);
             p.m_idpos[new_id] = i;
             p.m_hrefpos.remove(old_href);
             p.m_hrefpos[me.m_href] = i;
@@ -1039,7 +1037,7 @@ QString OPFResource::GetOPFDefaultText(const QString &version)
     SettingsStore ss;
     QString defaultLanguage = ss.defaultMetadataLang();
     if (version.startsWith('2')) {
-      return TEMPLATE_TEXT.arg(Utility::CreateUUID()).arg(defaultLanguage);
+        return TEMPLATE_TEXT.arg(Utility::CreateUUID()).arg(defaultLanguage);
     }
     return TEMPLATE3_TEXT.arg(Utility::CreateUUID()).arg(defaultLanguage);
 }
@@ -1057,7 +1055,7 @@ void OPFResource::FillWithDefaultText()
 QString OPFResource::GetUniqueID(const QString &preferred_id, const OPFParser& p) const
 {
     if (p.m_idpos.contains(preferred_id)) {
-        return Utility::CreateUUID();
+        return QString("x").append(Utility::CreateUUID());
     }
     return preferred_id;
 }
@@ -1065,7 +1063,11 @@ QString OPFResource::GetUniqueID(const QString &preferred_id, const OPFParser& p
 
 QString OPFResource::GetResourceMimetype(const Resource *resource) const
 {
-    return GetFileMimetype(resource->Filename());
+    QString mimetype = resource->GetMediaType();
+    if (mimetype.isEmpty()) {
+        mimetype = GetFileMimetype(resource->Filename());
+    }
+    return mimetype; 
 }
 
 
@@ -1105,6 +1107,7 @@ void OPFResource::CreateMimetypes()
     m_Mimetypes[ "webm"  ] = "video/webm";
     m_Mimetypes[ "smil"  ] = "application/smil+xml";
     m_Mimetypes[ "pls"   ] = "application/pls+xml";
+    m_Mimetypes[ "xpgt"  ] = "application/adobe-page-template+xml";
     m_Mimetypes[ "js"    ] = "text/javascript";
     // Until the standards gods grace us with font mimetypes,
     // these will have to do
@@ -1131,30 +1134,28 @@ void OPFResource::UpdateText(const OPFParser &p)
     TextResource::SetText(p.convert_to_xml());
 }
 
+
 QString OPFResource::ValidatePackageVersion(const QString& source)
 {
     QString newsource = source;
     QString orig_version = GetEpubVersion();
     QRegularExpression pkgversion_search(PKG_VERSION, QRegularExpression::CaseInsensitiveOption);
-    QRegularExpressionMatch pkgversion_mo = pkgversion_search.match(newsource);
-    QString version = "2.0";
-    if (pkgversion_mo.hasMatch()) {
-        version = pkgversion_mo.captured(1);
-    }
-    if (version != orig_version) {
-        OPFParser p;
-        p.parse(newsource);
-        p.m_package.m_version = orig_version;
-        newsource = p.convert_to_xml();
-        if (!m_WarnedAboutVersion && !version.startsWith('1')) {
-            Utility::DisplayStdWarningDialog("Changing package version inside Sigil is not supported", 
-                                             "Use an appropriate output plugin to make the initial conversion");
-            m_WarnedAboutVersion = true;
+    QRegularExpressionMatch mo = pkgversion_search.match(newsource);
+    if (mo.hasMatch()) {
+        QString version = mo.captured(1);
+        if (version != orig_version) {
+            newsource.replace(mo.capturedStart(1), mo.capturedLength(1), orig_version);
+            if (!m_WarnedAboutVersion && !version.startsWith('1')) {
+                Utility::DisplayStdWarningDialog("Changing package version inside Sigil is not supported", 
+                                                 "Use an appropriate output plugin to make the initial conversion");
+                m_WarnedAboutVersion = true;
+            }
         }
     }
     return newsource;
 }
 
+
 void OPFResource::UpdateManifestProperties(const QList<Resource*> resources)
 {
     QWriteLocker locker(&GetLock());
@@ -1200,6 +1201,49 @@ void OPFResource::UpdateManifestProperties(const QList<Resource*> resources)
 }
 
 
+QString OPFResource::GetManifestPropertiesForResource(const Resource * resource)
+{
+    QString properties;
+    if (!resource) return properties;
+    QReadLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
+    if (!p.m_package.m_version.startsWith("3")) {
+        return properties;
+    }
+    QString href = resource->GetRelativePathToOEBPS();
+    int pos = p.m_hrefpos.value(href, -1);
+    if ((pos >= 0) && (pos < p.m_manifest.count())) {
+        ManifestEntry me = p.m_manifest.at(pos);
+        properties = me.m_atts.value("properties","");
+    }
+    return properties;
+}
+
+
+QHash <QString, QString>  OPFResource::GetManifestPropertiesForPaths()
+{
+    QHash <QString, QString> manifest_properties_all;
+    QString version = GetEpubVersion();
+    if (!version.startsWith('3')) {
+        return manifest_properties_all;
+    }
+    QReadLocker locker(&GetLock());
+    QString source = CleanSource::ProcessXML(GetText(),"application/oebps-package+xml");
+    OPFParser p;
+    p.parse(source);
+    foreach(ManifestEntry me, p.m_manifest) {
+        QString href = me.m_href;
+        if (me.m_atts.contains("properties")){
+            QString properties = me.m_atts["properties"];
+            manifest_properties_all[href] = properties;
+        }
+    }
+    return manifest_properties_all;
+}
+
+
 HTMLResource * OPFResource::GetNavResource()const
 {
     return m_NavResource;
@@ -1226,6 +1270,7 @@ void OPFResource::SetNavResource(HTMLResource * nav_resource)
     }
 }
 
+
 void OPFResource::SetItemRefLinear(Resource * resource, bool linear)
 {
     QWriteLocker locker(&GetLock());
